@@ -24,10 +24,10 @@ class Profile:
 		    '---''(_/--'  `-'\\_)  miao miao 
 		'''
 		self.art2 = '''
-		 |\\__/,|   (`\
-		 |_ _   |.--.) )
-		 ( T    )     /
-		(((^_(((/(((_/
+		 _._     _,-'""`-._
+		(,-.`._,'(       |\\`-/|
+		    `-.-' \\ )-`( , o o)
+		          `-    \\`_`"'-
 		'''
 
 	def show_email(self):
